﻿#use(util.js)
#use(NaviDisplay.js)

var navi_display = null;
var uid_cnt = 0;
var curr_screen = null;
var curr_object = null;
var ct_map = {};
MacroSet.prototype.prev_elem_type_ = null;

function MacroSet() { }

MacroSet.prototype.build_globals = function(c) {
    if (!("global_params" in c)) c.global_params = new Object;

    var pc = new ParamChecker(c.defaults, "global", c.global_params, null);

    pc.Check("nohelp_explanation", "HTML", "");
    pc.Check("bmain_style", "SHELF", "darkred_border");
    pc.Check("bmain_position", "POSITION", {'left':600, 'top':200});
    pc.Check("bmain_width", "INTEGER", 300);
    pc.Check("bmain_height", "INTEGER", 260);
    pc.Check("bmain_minimizable", "BOOL_0_1", true);
    pc.Check("bubblestyle_d", "SHELF", "darkred_border");
    pc.Check("b_width", "INTEGER", 150);
    pc.Check("b_height", "INTEGER", 40);
    pc.Check("b_minimizable", "BOOL_0_1", true);
    pc.Check("b_minimized", "BOOL_0_1", true);
    pc.Check("orientation", "ORIENTATION_BUBBLE", "SE");
    pc.Check("no_spike", "BOOL_0_1", false);    
    pc.Check("bubble_offset", "POSITION", {'left':0, 'top':0});
    pc.Check("g_highlight_effect", "ENUM", "frame");
    pc.Check("g_highlight_border", "INTEGER", 3);
    pc.Check("g_highlight_bgr", "COLOR", "0x0036e0" );
}

MacroSet.prototype.start_unit = function(c, params) {
    var pc = new ParamChecker(c.defaults, "start_unit", params, c.global_params);

    pc.Check("uid", "TEXT", "");
    pc.Check("app_res_time", "INTEGER", 100);
    pc.Check("config_templates", "TXT_TEXT_LONG", "");
    
    winnavp_global.AppResponseTime = params.app_res_time;
    winnavp_global.ScreenTolerence = 6;
    
    winnavp_player.sim_src = winnavp_player.uid;
    
    if (params.config_templates != "") {
        var profiles = XmlFromString(params.config_templates);
        if (profiles) {
            var root = profiles.baseNode().getChild(0);
            var cnt = root.numChildren("CTFile");
            for (var i = 0; i < cnt; i++) {
                var child = root.getChild(i);
                if (child.hasAttribute("name")) { 
                    var config_file = child.getAttribute("name").getValue();
                    ct_map[config_file] = child.innerText(); 
                }
            }
        }
    }
    
    navi_display = new NaviDisplay(pc, params, c.global_params);
}

function check_merged_macros() {
    if (curr_screen.Macros.length > 0 && curr_screen.process_id != "*") {
        var new_window = new winnavp_Navigationstop();
        
        new_window.caption = curr_screen.caption;
        new_window.uid = ctx_nsuid + uid_cnt;
        new_window.muid = curr_screen.muid;
        new_window.text = curr_screen.text;
        new_window.sim_link = curr_screen.sim_link;
        new_window.process_id = "*";
        new_window.config_file = curr_screen.config_file;
        new_window.key = curr_screen.key;
        new_window.subkey = curr_screen.subkey;
        new_window.win_rect = curr_screen.win_rect.Clone();
        new_window.resize_win = curr_screen.resize_win;
        
        curr_screen = new_window;           
        
        navi_display.SetCtxWindow(curr_screen, navi_display.exe_, navi_display.appprofile_header_);
         
        uid_cnt += 1;
    }
    if (curr_object != null) {
        this.prev_elem_type_ = curr_object.element_type;
    }
}
            
        
MacroSet.prototype.new_page = function(c, params) {
    var pc = new ParamChecker(c.defaults, "new_page", params, c.global_params);

    pc.Check("uid", "TEXT", "");
    pc.Check("macro_comment", "TEXT", "");
    pc.Check("key", "TEXT_SHORT", "");
    pc.Check("executable", "TEXT", "");
    pc.Check("sc_config_file", "TEXT", "");
    pc.Check("screenshot_rect", "POSSIZE");
    pc.Check("new_step", "TEXT", "");
    
    var left = params.screenshot_rect.left - 0;
    var top = params.screenshot_rect.top - 0;
    var right = left + params.screenshot_rect.width;
    var bottom = top + params.screenshot_rect.height;

    curr_screen = new winnavp_Navigationstop();
    
    curr_screen.caption = params.new_step;
    curr_screen.uid = ctx_nsuid;
    curr_screen.muid = params.uid;
    curr_screen.text = "";
    curr_screen.sim_link = params.reference;
    curr_screen.process_id = "*";
    curr_screen.config_file = params.sc_config_file;
    curr_screen.key = params.key;
    curr_screen.subkey = 0;
    curr_screen.win_rect = CreateRect(left, top, right, bottom);
    curr_screen.resize_win = false;
    curr_screen.executable = params.executable;
    navi_display.SetCtxWindow(curr_screen, params.executable, ct_map[params.sc_config_file]);
           
    uid_cnt = 0;
}

MacroSet.prototype.explanation_long = function(c, params) {
    var pc = new ParamChecker(c.defaults, "explanation_long", params, c.global_params);

    pc.Check("uid", "TEXT", "");
    pc.Check("fieldname", "TEXT", "");
    pc.Check("position_b", "RELPOS");
    pc.Check("macro_comment", "TEXT", "");
    pc.Check("b_width", "INTEGER", "240");
    pc.Check("b_height", "INTEGER", "160");
     
    curr_object = new winnavp_Macro();
    
    curr_object.comment = params.macro_comment;
    curr_object.fieldicon = params.fieldicon;
    curr_object.uid = params.uid;
    curr_object.element_type='WINExplainLong';
    curr_object.enabled = 1;
    curr_object.ctrl_dependent = false;
    curr_object.fieldname = params.fieldname;
    curr_object.click_pos = {x:50, y:50};

    curr_object.bubble = navi_get_bubble(pc, params);
    curr_object.bubble.text = dgo_resolve(null, curr_object.bubble.text, 2);
    //navi_display.InsertCtxObjectBehaviour();
    
    if (curr_screen != null) curr_screen.Macros.push(curr_object);
}

MacroSet.prototype.click = function(c, params) {
    var pc = new ParamChecker(c.defaults, "click", params, c.global_params);

    pc.Check("uid", "TEXT", "");
    pc.Check("objname", "TEXT", "");
    pc.Check("fieldname", "TEXT", "");
    pc.Check("action", "ENUM", "lclick");
    pc.Check("element_type", "TEXT", "");
    pc.Check("click_pos", "POSITION");
    pc.Check("all_values", "TEXT_SHORT", "");
    pc.Check("screenshot_rect", "POSSIZE");
    pc.Check("elem_key", "TEXT_SHORT", "");
    pc.Check("macro_comment", "TEXT", "");
    pc.Check("autopilot", "ENUM", "automatic");
    pc.Check("key_desc", "TEXT", "");
    
    if ( params.element_type.indexOf("Scroll") != -1){
        return;
    }
        
    if (curr_object != null && params.element_type == "WINCBListItem") {
      
      if(handle_combo(curr_object.element_type)) {
          curr_object.value = params.fieldname;
          return;
      }
    }
    //MENUE WA
    /*var last_was_menue = false;
    if (curr_object != null && params.element_type == "WINGeneralMenue") {
        last_was_menue = true;
    }*/

    params["objname"] = params.uid;
    
    if (curr_screen != null) {
        curr_object = null;

        if (curr_object == null) {
            curr_object = new winnavp_Macro();
            curr_object.comment = params.macro_comment;
            curr_object.fieldicon = params.fieldicon;
            curr_object.uid = params.uid;
            curr_object.objectname = params.objname;
            curr_object.fieldname = params.fieldname;
            curr_object.enabled = 1;
            curr_object.action = params.action;
            curr_object.bubble_enabled = 1;
            curr_object.hilight_enabled = 1;
            curr_object.element_type = params.element_type;
            curr_object.click_pos = {x: params.click_pos.left - 0, y: params.click_pos.top - 0};
            curr_object.all_values = params.all_values;
            curr_object.path = params.elem_key;
            curr_object.leaves_page = 0;
            curr_object.validatory = 0;
            curr_object.hot_key = params.key_desc;
            if (params.element_type == "WINHotspotArea" || params.element_type == "WINHotspotMenue" ||
               //MENUE WA
               //(params.element_type == "WINGeneralMenue" && last_was_menue) ||
               (params.elem_key == ""))
            {
                var left = params.screenshot_rect.left - 0;
                var top = params.screenshot_rect.top - 0;
                var right = left + params.screenshot_rect.width;
                var bottom = top + params.screenshot_rect.height;

                curr_object.rect = CreateRect(left, top, right, bottom);
                curr_object.element_type = 'WINActiveArea';
                curr_object.path = "";
            }

            curr_object.bubble = navi_get_bubble(pc, params);
        
            check_merged_macros();
            navi_display.InsertCtxObjectBehaviour(params, "click");
            curr_screen.Macros.push(curr_object);
        }
    }
}

MacroSet.prototype.key_press = function(c, params) {
    var pc = new ParamChecker(c.defaults, "active_area", params, c.global_params);

    pc.Check("uid", "TEXT", "");
    pc.Check("objname", "TEXT", "");
    pc.Check("key_desc", "TEXT", "");
    pc.Check("path", "TEXT_SHORT", "");
    pc.Check("macro_comment", "TEXT", "");
    pc.Check("autopilot", "ENUM", "automatic");
    
    params["objname"] = params.uid;
    
    curr_object = new winnavp_Macro();
    
    curr_object.comment = params.macro_comment;
    curr_object.fieldicon = params.fieldicon;
    curr_object.uid = params.uid;
    curr_object.objectname = params.objname;
    curr_object.fieldname = params.key_desc;
    curr_object.enabled = 1;
    curr_object.click_pos = {x:50, y:50};
    curr_object.path = params.path;
    curr_object.leaves_page = 0;
    curr_object.ctrl_dependent = false;
    curr_object.element_type='WINKeyPress';

    curr_object.bubble = navi_get_bubble(pc, params);

    check_merged_macros();
    navi_display.InsertCtxObjectBehaviour(params, "key_press");
    if (curr_screen != null) curr_screen.Macros.push(curr_object);
}

MacroSet.prototype.input_text = function(c, params) {
    var pc = new ParamChecker(c.defaults, "input_text", params, c.global_params);

    pc.Check("uid", "TEXT", "");
    pc.Check("objname", "TEXT", "");
    pc.Check("fieldname", "TEXT", "");
    pc.Check("text_d", "TEXT", "");
    pc.Check("action", "ENUM", "lclick");
    pc.Check("element_type", "TEXT", "");
    pc.Check("click_pos", "POSITION");
    pc.Check("all_values", "TEXT_SHORT", "");
    pc.Check("screenshot_rect", "POSSIZE");
    pc.Check("confirmation_key", "TEXT", "");
    pc.Check("elem_key", "TEXT_SHORT", "");
    pc.Check("macro_comment", "TEXT", "");
    pc.Check("autopilot", "ENUM", "ask");
    
    params["objname"] = params.uid;
    
    if (curr_screen != null) {
        curr_object = null;
        
        if (curr_object == null) {
            curr_object = new winnavp_Macro();
            
            curr_object.comment = params.macro_comment;
            curr_object.fieldicon = params.fieldicon;
            curr_object.uid = params.uid;
            curr_object.objectname = params.objname;
            curr_object.fieldname = params.fieldname;
            curr_object.value = params.text_d;
            curr_object.all_values = params.all_values;
            curr_object.enabled = 1;
            curr_object.action = params.action;
            curr_object.bubble_enabled = 1;
            curr_object.hilight_enabled = 1;
            curr_object.element_type = params.element_type;
            curr_object.sim_element_type = params.element_type;
            curr_object.click_pos = {x: params.click_pos.left - 0, y: params.click_pos.top - 0};
            curr_object.path = params.elem_key;
            curr_object.leaves_page = 0;
            curr_object.validatory = 0;
            
            curr_object.confirm_with_enter = (params.confirmation_key == "enter");
            curr_object.bubble = navi_get_bubble(pc, params);
        
            if (params.element_type == "WINHotspotEdit") {
                var left = params.screenshot_rect.left - 0;
                var top = params.screenshot_rect.top - 0;
                var right = left + params.screenshot_rect.width;
                var bottom = top + params.screenshot_rect.height;
                
                curr_object.rect = CreateRect(left, top, right, bottom);
                
                curr_object.element_type = 'WINActiveArea';
                curr_object.path = "";
            }
            
            check_merged_macros();
            navi_display.InsertCtxObjectBehaviour(params, "input_text");
            curr_screen.Macros.push(curr_object);
        }
    }
}

MacroSet.prototype.select_single = function(c, params) {
    var pc = new ParamChecker(c.defaults, "select_single", params, c.global_params);

    pc.Check("uid", "TEXT", "");
    pc.Check("objname", "TEXT", "");
    pc.Check("fieldname", "TEXT", "");
    pc.Check("choose_text", "TEXT", "");
    pc.Check("action", "ENUM", "lclick");
    pc.Check("element_type", "TEXT", "");
    pc.Check("click_pos", "POSITION");
    pc.Check("elem_key", "TEXT_SHORT", "");
    pc.Check("all_values", "TEXT_SHORT", "");
    pc.Check("macro_comment", "TEXT", "");
    pc.Check("autopilot", "ENUM", "ask");
    
    params["objname"] = params.uid;
    
    if (curr_screen != null) {
        curr_object = null;
        
        if (curr_object == null) {
            curr_object = new winnavp_Macro();
            
            curr_object.comment = params.macro_comment;
            curr_object.fieldicon = params.fieldicon;
            curr_object.uid = params.uid;
            curr_object.objectname = params.objname;
            curr_object.fieldname = params.fieldname;
            curr_object.value = params.choose_text;
            curr_object.all_values = params.all_values;
            curr_object.enabled = 1;
            curr_object.action = params.action;
            curr_object.bubble_enabled = 1;
            curr_object.hilight_enabled = 1;
            curr_object.element_type = params.element_type;
            curr_object.click_pos = {x: params.click_pos.left - 0, y: params.click_pos.top - 0};
            curr_object.path = params.elem_key;
            curr_object.leaves_page = 0;
            curr_object.validatory = 0;
        
            curr_object.bubble = navi_get_bubble(pc, params);
            
            check_merged_macros();
            navi_display.InsertCtxObjectBehaviour(params, "select_single");
            curr_screen.Macros.push(curr_object);
        }
    }
}

MacroSet.prototype.input_radio = function(c, params) {
    var pc = new ParamChecker(c.defaults, "input_radio", params, c.global_params);

    pc.Check("uid", "TEXT", "");
    pc.Check("objname", "TEXT", "");
    pc.Check("fieldname", "TEXT", "");
    pc.Check("choose_bool", "TEXT", "");
    pc.Check("action", "ENUM", "lclick");
    pc.Check("element_type", "TEXT", "");
    pc.Check("click_pos", "POSITION");
    pc.Check("elem_key", "TEXT_SHORT", "");
    pc.Check("macro_comment", "TEXT", "");
     pc.Check("autopilot", "ENUM", "ask");
    
    params["objname"] = params.uid;
    
    if (curr_screen != null) {
        curr_object = null;
        
        if (curr_object == null) {
            curr_object = new winnavp_Macro();
            
            curr_object.comment = params.macro_comment;
            curr_object.fieldicon = params.fieldicon;
            curr_object.uid = params.uid;
            curr_object.objectname = params.objname;
            curr_object.fieldname = params.fieldname;
            curr_object.value = params.choose_bool;
            curr_object.enabled = 1;
            curr_object.action = params.action;
            curr_object.bubble_enabled = 1;
            curr_object.hilight_enabled = 1;
            curr_object.element_type = params.element_type;
            curr_object.click_pos = {x: params.click_pos.left - 0, y: params.click_pos.top - 0};
            curr_object.path = params.elem_key;
            curr_object.leaves_page = 0;
            curr_object.validatory = 0;
        
            curr_object.bubble = navi_get_bubble(pc, params);
            
            check_merged_macros();
            navi_display.InsertCtxObjectBehaviour(params, "input_radio");
            curr_screen.Macros.push(curr_object);
        }
    }
}

MacroSet.prototype.Loaded = function() {
    navi_display.Finalize();
}

function handle_combo(elem_type){
  if (elem_type == "WINExplainLong") {
      elem_type = this.prev_elem_type_;
  }
  
  if (elem_type == "WINButtonCombo" || elem_type == "WINComboButtontpcd" || elem_type == "WINClick" ) {
      return true;
  }
  return false;
}
  
